//+-------------------------------------------------------------------------------------------+
//|                                                                                           |
//|                                  SonicR Dragon-Trend.mq4                                  |
//|                                                                                           |
//+-------------------------------------------------------------------------------------------+ 
#property copyright "Copyright @ 2011 traderathome"
#property link      "email: traderathome@msn.com"

/*---------------------------------------------------------------------------------------------
Overview:

This indicator displays the SonicR Dragon and Trend.  You can specify a separate "Control" MA
for the Dragon, and apply to various TFs.  This feature can be turned On/Off for the various 
TFs independently.

The indicator can be turned on/off without having to remove it from the chart, preserving your
chart settings.  And you can select a range of TFs for its display, so that it automatically 
will not display if you change the chart to a TF beyond that range.
                               
                                                                     - Traderathome, 06-15-2011  
----------------------------------------------------------------------------------------------- 
Suggested Settings:          White Chart      w/VA Candles     Black Chart      w/VA Candles

Dragon-
#property indicator_color1   DeepSkyBlue      DeepSkyBlue      SteelBlue        SteelBlue
#property indicator_color2   LightSlateGray   LightSlateGray   C'181,181,181'   DarkGray
#property indicator_color3   SpringGreen      LightGray        C'0,164,0'       Gray
#property indicator_color4   DeepSkyBlue      DeepSkyBlue      SteelBlue        SteelBlue
#property indicator_width1   1                1                1                1
#property indicator_width2   5                5                4                4
#property indicator_width3   3                3                2                2
#property indicator_width4   1                1                1                1
#property indicator_style1   STYLE_SOLID      STYLE_SOLID      STYLE_SOLID      STYLE_SOLID
#property indicator_style2   STYLE_SOLID      STYLE_SOLID      STYLE_SOLID      STYLE_SOLID
#property indicator_style3   STYLE_SOLID      STYLE_SOLID      STYLE_SOLID      STYLE_SOLID
#property indicator_style4   STYLE_SOLID      STYLE_SOLID      STYLE_SOLID      STYLE_SOLID

Trend-
#property indicator_color5   C'230,0,230'     C'230,0,230'     C'215,0,215'     C'215,0,215'
#property indicator_color6   LightGray        LightGray        LightSlateGray   LightSlateGray
#property indicator_width5   2                2                2                2
#property indicator_width6   1                1                1                1
#property indicator_style5   STYLE_SOLID      STYLE_SOLID      STYLE_SOLID      STYLE_SOLID
#property indicator_style6   STYLE_DOT        STYLE_DOT        STYLE_DOT        STYLE_DOT                                                                                     
---------------------------------------------------------------------------------------------*/


//+-------------------------------------------------------------------------------------------+
//| Indicator Global Inputs                                                                   |                                                        
//+-------------------------------------------------------------------------------------------+ 
#property indicator_chart_window

//Dragon-
#property indicator_buffers  6
#property indicator_color1   DeepSkyBlue 
#property indicator_color2   LightSlateGray
#property indicator_color3   LightGray
#property indicator_color4   DeepSkyBlue
#property indicator_width1   1
#property indicator_width2   5
#property indicator_width3   3
#property indicator_width4   1
#property indicator_style1   STYLE_SOLID
#property indicator_style2   STYLE_SOLID
#property indicator_style3   STYLE_SOLID
#property indicator_style4   STYLE_SOLID 

//Trend-
#property indicator_color5   C'230,0,230'
#property indicator_color6   LightGray
#property indicator_width5   2
#property indicator_width6   1
#property indicator_style5   STYLE_SOLID
#property indicator_style6   STYLE_DOT 

//global external inputs
extern string Part_1                          = "Indicator Display Controls:";
extern bool   Indicator_On                    = true;
extern int    Display_Min_TF                  = 1;
extern int    Display_Max_TF                  = 43200;
extern string TF_Choices_1                    = "M1 - H4 =  1, 5, 15, 30, 60, 240";
extern string TF_Choices_2                    = "D  W  M =  1440,  10080,  43200";

extern string __                              = "";
extern string Part_2                          = "Dragon Settings:";
extern bool   Dragon_On                       = true;
extern int    Dragon_MA                       = 34;
extern bool   Dragon_MA_Exp_vs_Simple         = true;
extern bool   Center_Line_Close_vs_Median     = true;
extern int    Dragon_M30_Control_TF           = 15;
extern bool   Dragon_M30_Control_TF_On        = false;
extern int    Dragon_H1_Control_TF            = 30;
extern bool   Dragon_H1_Control_TF_On         = true;
extern int    Dragon_H4_Control_TF            = 60;
extern bool   Dragon_H4_Control_TF_On         = true;
extern int    Dragon_D1_Control_TF            = 240;
extern bool   Dragon_D1_Control_TF_On         = true;

extern string ___                             = "";
extern string Part_3                          = "Trend Settings:";
extern bool   Trend_On                        = true;
extern int    Trend_MA                        = 89;
extern bool   Trend_MA_Exp_vs_Simple          = true;

//global buffers and variables
bool    FLAG_deinit;
int     i,counted_bars,limit,BarShift,Factor,Dragon_Control_TF;

double  MAhighBuffer[], MAcenterBuffer1[], MAcenterBuffer2[], MAlowBuffer[];
int     Dragon_MA_Type                = 0;
string  Dragon_Type_Choices           = "0=SMA, 1=EMA";
int     Centerline                    = 0;
string  Centerline_Choices            = "0=CLOSE, 4=MEDIAN";

double  TrendBuffer1[], TrendBuffer2[];
int     Trend_MA_Type                 = 0;
string  MA_Type_Choices               = "0=SMA, 1=EMA";
int     Trend_MA_Price                = 0;
string  MA_Price_Choices              = "0=C  1=O  2=H  3=L  4=M  5=P  6=W"; 
 
//+-------------------------------------------------------------------------------------------+
//| Indicator Initialization                                                                  |                                                        
//+-------------------------------------------------------------------------------------------+      
int init()
   {
   FLAG_deinit = false;
   
   //Test if Dragon is to be diplayed     
   if (Dragon_On)
      {   
      Dragon_MA_Type = 0; if (Dragon_MA_Exp_vs_Simple) {Dragon_MA_Type = 1;}   
      Centerline = 0; if (!Center_Line_Close_vs_Median) {Centerline = 4;}     
      SetIndexBuffer(0, MAhighBuffer);
      SetIndexBuffer(1, MAcenterBuffer1);
      SetIndexBuffer(2, MAcenterBuffer2);  
      SetIndexBuffer(3, MAlowBuffer);
      SetIndexStyle(0, DRAW_LINE);
      SetIndexStyle(1, DRAW_LINE);   
      SetIndexStyle(2, DRAW_LINE);
      SetIndexStyle(3, DRAW_LINE);
      SetIndexEmptyValue(0,0);
      SetIndexEmptyValue(1,0);
      SetIndexEmptyValue(2,0);
      SetIndexEmptyValue(3,0);              
      }//end Dragon
                                    
   //Test if Trend is to be diplayed  
   if (Trend_On) 
      {  
      Trend_MA_Type = 0; if (Trend_MA_Exp_vs_Simple) {Trend_MA_Type = 1;}   
      SetIndexBuffer(4, TrendBuffer1);
      SetIndexBuffer(5, TrendBuffer2);                  
      SetIndexStyle(4, DRAW_LINE);
      SetIndexStyle(5, DRAW_LINE);                
      SetIndexEmptyValue(4,0); 
      SetIndexEmptyValue(5,0); 
      }//end Trend
      
   //Indicator Short Name                     
   IndicatorShortName("SonicR Dragon-Trend");                     
                
   return(0);
   }

//+-------------------------------------------------------------------------------------------+
//| Indicator De-initialization                                                               |                                                        
//+-------------------------------------------------------------------------------------------+      
int deinit()
   {      
   return(0);
   }

//+-------------------------------------------------------------------------------------------+
//| Indicator Start                                                                           |                                                        
//+-------------------------------------------------------------------------------------------+     
int start()
   {
   //If indicator is "Off" or chart TF is out of range deinitialize only once, not every tick.  
   if((!Indicator_On) || ((Period() < Display_Min_TF) || (Period() > Display_Max_TF)))    
      {
      if (!FLAG_deinit) {deinit(); FLAG_deinit = true;}
      return(0);
      }

   //Otherwise indicator is "On" & chart TF is in display range, so proceed.   
   deinit(); FLAG_deinit = false;
                       
   //Calculate MAs   
   //check for possible errors
   counted_bars = IndicatorCounted();
   if(counted_bars < 0)  return(-1); 
     
   //last counted bar will be recounted
   if(counted_bars > 0) counted_bars--;    
   limit = Bars - counted_bars;

   for(i = limit - 1; i >= 0; i--)
      {
      if (Dragon_On)
         {
         Dragon_Control_TF = 0;
         if ((Dragon_M30_Control_TF_On) && (Period() == 30)) {Dragon_Control_TF = Dragon_M30_Control_TF;}
         else {if ((Dragon_H1_Control_TF_On) && (Period() == 60)) {Dragon_Control_TF = Dragon_H1_Control_TF;}
         else {if ((Dragon_H4_Control_TF_On) && (Period() == 240)) {Dragon_Control_TF = Dragon_H4_Control_TF;} 
         else {if ((Dragon_D1_Control_TF_On) && (Period() == 1440)) {Dragon_Control_TF = Dragon_D1_Control_TF;} }}}
  
         if (Dragon_Control_TF != 0)
            { 
            BarShift = iBarShift(NULL,Dragon_Control_TF,Time[i],true); 
            MAhighBuffer[i]    = iMA(NULL,Dragon_Control_TF,Dragon_MA,0,Dragon_MA_Type,PRICE_HIGH,BarShift);       
            MAcenterBuffer1[i] = iMA(NULL,Dragon_Control_TF,Dragon_MA,0,Dragon_MA_Type,Centerline,BarShift); 
            MAcenterBuffer2[i] = iMA(NULL,Dragon_Control_TF,Dragon_MA,0,Dragon_MA_Type,Centerline,BarShift); 
            MAlowBuffer[i]     = iMA(NULL,Dragon_Control_TF,Dragon_MA,0,Dragon_MA_Type,PRICE_LOW,BarShift); 
            }
             
         else    
            {              
            BarShift = iBarShift(NULL,NULL,Time[i],true);         
            MAhighBuffer[i]    = iMA(NULL,NULL,Dragon_MA,0,Dragon_MA_Type,PRICE_HIGH,BarShift);       
            MAcenterBuffer1[i] = iMA(NULL,NULL,Dragon_MA,0,Dragon_MA_Type,Centerline,BarShift);
            MAcenterBuffer2[i] = iMA(NULL,NULL,Dragon_MA,0,Dragon_MA_Type,Centerline,BarShift); 
            MAlowBuffer[i]     = iMA(NULL,NULL,Dragon_MA,0,Dragon_MA_Type,PRICE_LOW,BarShift);
            }
         }
         
      if (Trend_On)   
         {
         BarShift = iBarShift(NULL,NULL,Time[i],true);                 
         TrendBuffer1[i]    = iMA(NULL,NULL,Trend_MA,0,Trend_MA_Type,Trend_MA_Price,BarShift); 
         TrendBuffer2[i]    = iMA(NULL,NULL,Trend_MA,0,Trend_MA_Type,Trend_MA_Price,BarShift);              
         }
      }                
                           
   return(0);
   }

//+-------------------------------------------------------------------------------------------+
//| Indicator End                                                                             |                                                        
//+-------------------------------------------------------------------------------------------+       

